% FB_optim_freq: Optimization of the frequency responses of a synthesis FB 
% Mcurt2=FB_optim_freq(Hcurt,Mcurt,N,k,k2,P1,P2)
%
% FB_optim_freq: This function performs the optimization of the synthesis
% FB using a cost function on frequency responses aiming at concentrating
% them. This cost function is denoted J_{f} in Jerome Gauthier's PhD thesis.
%
% Hcurt is a matrix describing the analysis FB (see FB_GEN for details)
% Mcurt is a matrix describing one synthesis FB (see FB_GEN for details)
% N is the downsampling factor 
% k2 is the redundancy factor (k' in articles)
% P1, P2 are the overlapping factors for the synthesis FB
%
% Example :
%  N=8; k=3; k2=7/4;
%  [Mcurt,P1,P2,M,Hcurt]=FB_gen(N,k,k2);
%  Mcurt2=FB_optim_freq(Hcurt,Mcurt,N,k,k2,P1,P2);
%
% See also FB_GEN, FB_OPTIM_IMPUL.
%
% Input:        Hcurt, Mcurt (array of double/complex), N, k, P1, P2 (int)
%               k2 (double)
% Optional:     
% Output:       Mcurt2 (array of double/complex)
% Uses:         cent5
% Used in:
% Comments:
% Notes:
% Created:      2007/08/28
% Modified:      
%
%   Authors: Laurent C. Duval, laurent.duval@ifp.fr
%            Jrme Gauthier, jerome.gauthier@ifp.fr
%   Institution: IFP, Technology Department
%   (c) All right reserved




