% FB_optim_impul_sym: Optimization of symmetric synthesis FB using built-in function.
% Mcurt2=FB_optim_impul_sym(HcurtR,McurtR,N,k,k2,P1,P2)
%
% FB_optim_impul_sym: This function performs the optimization of the synthesis
% FB in the symmetric case using a cost function on impulse responses aiming 
% at concentrating them. This cost function is denoted J_{ts} in Jerome
% Gauthier's PhD thesis.
%
% HcurtR is a matrix describing the analysis FB (see FB_GEN for details)
% McurtR is a matrix describing one synthesis FB (see FB_GEN for details)
% N is the downsampling factor 
% k2 is the redundancy factor (k' in articles)
% P1, P2 are the overlapping factors for the synthesis FB
%
% Example :
%  N=8; k=3; k2=7/4;
%  [McurtR,P1,P2,M,HcurtR]=FB_gen_sym(N,k,k2);
%  Mcurt2=FB_optim_impul_sym(HcurtR,McurtR,N,k,k2,P1,P2);
%
% See also FB_GEN_SYM, FB_OPTIM_FREQ_SYM.
%
% Input:        HcurtR, McurtR (array of double), N, k, P1, P2 (int)
%               k2 (double)
% Optional:     
% Output:       Mcurt2 (array of double/complex)
% Uses:         cent8
% Used in:
% Comments:
% Notes:
% Created:      2007/08/28
% Modified:      
%
%   Authors: Laurent C. Duval, laurent.duval@ifp.fr
%            Jrme Gauthier, jerome.gauthier@ifp.fr
%   Institution: IFP, Technology Department
%   (c) All right reserved
