% polyphase2impul: Converts polyphase matrix into impulse coefficients. 
% htilde=polyphase2impul(N,k,k2,P1,P2,Mcurt,dis)
%
% polyphase2impul: This function converts the polyphase matrix Mcurt into a
% matrix containing the impulse coefficients of the synthesis filters.
%
% Inputs:
% N is the downsampling factor 
% k overlapping factor of the analysis FB.
% k2 is the redundancy factor (k' in articles)
% P1, P2 are the overlapping factors for the synthesis FB.
% Mcurt is a matrix describing one synthesis FB (see FB_gen for details)
% dis (optional) is an integer, if it's value is not 0 then it will display
% the impulse and frequency responses of the synthesis FB
% Outputs:
% htilde is the matrix with the impulse coefficients of the synthesis FB.
%
% Example :
%  N=8; k=3; k2=7/4;
%  [Mcurt,P1,P2,M,Hcurt]=FB_gen(N,k,k2);
%  htilde=polyphase2impul(N,k,k2,P1,P2,Mcurt,1);
%
% See also FB_GEN.
%
% Input:        Mcurt (array of double/complex), N, k, P (int), k2 (double)
% Optional:     dis (int)
% Output:       htilde (array of double/complex)
% Uses:         
% Used in:
% Comments:
% Notes:
% Created:      2007/08/28
% Modified:     2008/10/17 
%
%   Authors: Laurent C. Duval, laurent.duval@ifp.fr
%            Jrme Gauthier, jerome.gauthier@ifp.fr
%   Institution: IFP, Technology Department
%   (c) All right reserved
